@@ -4,9 +4,14 @@ use Dancer;
 use Plack::Builder;
 
 {
+
     package UsageMetrics;
     use Dancer ':syntax';
 
+    get '/' => sub {
+        return "This is our startpage.";
+    };
+
     get '/record/123' => sub {
         return "View this record";
     };
@@ -23,19 +28,18 @@ use Plack::Builder;
 }
 
 my $app = sub {
-    my $env     = shift;
+    my $env = shift;
     my $request = Dancer::Request->new(env => $env);
     Dancer->dance($request);
 };
 
-
 builder {
     enable "Plack::Middleware::Matomo",
-        id_site => "my_repo",
-        base_url => "http://localhost:5000/matomo",
-        # api_key => "secr3t",
-        view_paths => ['record/(\w+)/*'],
-        download_paths => ['download/(\w+)/*'],
+        idsite                => "1",
+        base_url              => "http://localhost:5000/matomo",
+        token_auth            => "secr3t",
+        view_paths            => ['record/(\w+)/*'],
+        download_paths        => ['download/(\w+)/*'],
         oai_identifier_format => 'oai:test.server.org:%s',
         ;
     $app;
